@@ -21,8 +21,6 @@ class FailOnlyPlugin(nose.plugins.Plugin):
     # Interface functions
     #
     def options(self, parser, env):
-        super(FailOnlyPlugin, self).options(parser, env)
-
         parser.add_option(
             '--run-count',
             default=0,
@@ -32,16 +30,14 @@ class FailOnlyPlugin(nose.plugins.Plugin):
         )
 
     def configure(self, options, config):
-        super(FailOnlyPlugin, self).configure(options, config)
-
         if options.run_count <= 0 or getattr(options, 'statistics_file', None) is None:
             return
 
-        if not os.path.isfile(options.statistics_file):
+        if not self._os_isfile(options.statistics_file):
             return
 
         self.run_count = options.run_count
-        self.statistic = Statistic(options.statistics_file)
+        self.statistic = self._get_statistics(options.statistics_file)
         self.failpaths = self.statistic.get_failure_paths(self.run_count)
         self.enabled = True
 
@@ -53,3 +49,9 @@ class FailOnlyPlugin(nose.plugins.Plugin):
         return self.check_if_failed(func)
 
     wantMethod = wantFunction
+
+    def _get_statistics(self, filename):
+        return Statistic(filename)
+
+    def _os_isfile(self, filename):
+        return os.path.isfile(filename)
